<?php

/**
 * @file
 * Default theme implementation to display a Kaltura video using dynamic embed.
 *
 * Available variables:
 * - $domain: The domain of the Kaltura server.
 * - $partner_id: The partner ID of the Kaltura server user account.
 * - $subpartner_id: The sub-partner ID of the Kaltura server user account.
 * - $uiconf_id: The configuration ID of the Kaltura UI player.
 * - $entry_id: The entry ID of the Kaltura media to play.
 * - $player_id: The player ID of the div containing the player.
 * - $width: The width or max-width of the player.
 * - $height: The height or max-height of the player.
 * - $session: The KS session key.
 * - $title: The title of the file, or false if not set.
 * - $autoplay: Boolean determining whether to autoplay media.
 * - $options: The display options set in the formatter.
 *
 * Note: Make sure the div wrapper is preserved if you change this template, as
 * WYSIWYG insert relies on it.
 */
?>
<div>
  <div id="<?php print $player_id; ?>" style="width:<?php print $width; ?>px; height:<?php print $height; ?>px;"></div>
  <script type="application/javascript">
    (function () {
      'use strict';

      // Load kWidget if it hasn't been loaded on this page yet.
      if (typeof(kWidget) === 'undefined' && typeof(kWidgetLoaded) === 'undefined') {
        window.kWidgetLoaded = true;
        var script = document.createElement('script');
        script.type = 'text/javascript';
        script.src = '//<?php print $domain; ?>/p/<?php print $partner_id; ?>/sp/<?php print $subpartner_id; ?>/embedIframeJs/uiconf_id/<?php print $uiconf_id; ?>/partner_id/<?php print $partner_id; ?>';
        script.onload = function() {
          embedPlayer();
        };
        document.head.appendChild(script);
      }
      else {
        kWidgetStatus();
      }

      // Continually check for kWidget until loaded.
      function kWidgetStatus() {
        if (typeof(kWidget) === 'undefined') {
          setTimeout(function () {
            if (typeof(kWidget) === 'undefined') {
              kWidgetStatus();
            }
            else {
              embedPlayer();
            }
          }, 50)
        }
        else {
          embedPlayer();
        }
      }

      // Embed kWidget player.
      function embedPlayer() {
        var conf = {
          targetId: '<?php print $player_id; ?>',
          wid: '_<?php print $partner_id; ?>',
          uiconf_id: '<?php print $uiconf_id; ?>',
          entry_id: '<?php print $entry_id; ?>',
          flashvars: {},
          params: {
            'wmode': 'transparent'
          }
        };
        var title = '<?php print $title; ?>';
        var logo_img = '<?php print $logo_img; ?>';
        var logo_href = '<?php print $logo_img; ?>';
        var logo_title = '<?php print $logo_img; ?>';

        // Lead with HTML5 if supported. Also don't add title label or logo if
        // using flash since there seems to be an issue with loading the plugin.
        if (kWidget.supportsHTML5()) {
          mw.setConfig('KalturaSupport.LeadWithHTML5', true);

          // Override player title if enabled.
          if (title.length) {
            conf.flashvars.titleLabel = {
              'plugin': true,
              'align': 'left',
              'text': title
            };
          }

          // Override player logo if enabled.
          if (logo_img.length && logo_href.length && logo_title.length) {
            conf.flashvars.logo = {
              'plugin': true,
              'img': logo_img,
              'href': logo_href,
              'title': logo_title
            };
          }
        }

        // Set auto play option.
        conf.flashvars.autoPlay = <?php print $autoplay; ?>;

        // Enable KS auth if relevant.
        conf.flashvars.ks = '<?php print $session; ?>';

        // Embed the video.
        kWidget.embed(conf);
      }
    }());
  </script>
</div>
