<?php

/**
 * @file
 * Media: Kaltura theme functions.
 */

/**
 * Add variables to Media: Kaltura templates.
 */
function media_kaltura_preprocess(&$variables, $hook) {

  // Add general variables to all Kaltura media.
  switch ($hook) {
    case 'media_kaltura__video_dynamic':
    case 'media_kaltura__video_auto':
    case 'media_kaltura__video_thumbnail':
    case 'media_kaltura__video_responsive':
    case 'media_kaltura__video_iframe':
    case 'media_kaltura__audio_dynamic':
    case 'media_kaltura__audio_auto':
    case 'media_kaltura__audio_thumbnail':
    case 'media_kaltura__audio_responsive':
    case 'media_kaltura__audio_iframe':
      $file = $variables['file'];

      if ($server = media_kaltura_server_load_from_file($file)) {
        $kaltura = media_kaltura_start_session($server);

        $domain = $server->domain;
        $partner_id = $server->partner_id;
        $subpartner_id = $server->subpartner_id;
        $uiconf_id = $server->uiconf_id;
        $entry_id = $server->entry_id;
      }
      else {
        $wrapper = file_stream_wrapper_get_instance_by_uri($file->uri);
        $parameters = $wrapper->get_parameters();

        $domain = $parameters['domain'];
        $partner_id = $parameters['partner_id'];
        $subpartner_id = $parameters['subpartner_id'];
        $uiconf_id = $parameters['uiconf_id'];
        $entry_id = $parameters['entry_id'];
      }

      // Set KS session if applicable.
      $variables['session'] = FALSE;
      if ($variables['options']['session'] && isset($kaltura['session'])) {
        $variables['session'] = $kaltura['session'];
      }

      // Set title if applicable.
      $variables['title'] = FALSE;
      if ($variables['options']['title']) {
        $variables['title'] = $file->filename;
      }

      // Set logo if applicable.
      $variables['logo_img'] = $variables['options']['logo'] ? theme_get_setting('logo') : '';
      $variables['logo_href'] = $variables['options']['logo'] ? $GLOBALS['base_url'] : '';
      $variables['logo_title'] = $variables['options']['logo'] ? variable_get('site_name') : '';

      // Set required variables.
      $variables['domain'] = $domain;
      $variables['partner_id'] = $partner_id;
      $variables['subpartner_id'] = $subpartner_id;
      $variables['uiconf_id'] = $uiconf_id;
      $variables['entry_id'] = $entry_id;
      $variables['player_id'] = uniqid('kaltura_player_');
      $variables['width'] = $variables['options']['width'];
      $variables['height'] = $variables['options']['height'];
      $variables['autoplay'] = $variables['options']['autoplay'] ? 'true' : 'false';

      // Adds fix for kaltura.com using a separate domain name for ssl.
      // TODO: Find a more elegant way to choose http or https.
      $parse_url = parse_url($GLOBALS['base_url']);
      if ($variables['domain'] === 'cdnapi.kaltura.com' && $parse_url['scheme'] === 'https') {
        $variables['domain'] = 'cdnapisec.kaltura.com';
      }
      break;
  }

  // Add iFrame specific variables.
  switch ($hook) {
    case 'media_kaltura__video_iframe':
    case 'media_kaltura__audio_iframe':
      $variables['src'] = '//' . $variables['domain'];
      $variables['src'] .= '/p/' . $variables['partner_id'];
      $variables['src'] .= '/sp/' . $variables['subpartner_id'];
      $variables['src'] .= '/embedIframeJs';
      $variables['src'] .= '/uiconf_id/' . $variables['uiconf_id'];
      $variables['src'] .= '/partner_id/' . $variables['partner_id'];
      $variables['src'] .= '?iframeembed=true';
      $variables['src'] .= '&playerId=' . $variables['player_id'];
      $variables['src'] .= '&entry_id=' . $variables['entry_id'];
      $variables['src'] .= '&flashvars[autoPlay]=' . $variables['autoplay'];
      $variables['src'] .= '&flashvars[streamerType]=auto';
      $variables['src'] .= '&flashvars[forceMobileHTML5]=true';

      // Add logo to src url.
      if ($variables['options']['logo']) {
        $variables['src'] .= '&flashvars[logo.plugin]=true';
        $variables['src'] .= '&flashvars[logo.img]=' . $variables['logo_img'];
        $variables['src'] .= '&flashvars[logo.href]=' . $variables['logo_href'];
        $variables['src'] .= '&flashvars[logo.title]=' . $variables['logo_title'];
      }

      // Add title to src url.
      if ($variables['options']['title']) {
        $variables['src'] .= '&flashvars[titleLabel.plugin]=true';
        $variables['src'] .= '&flashvars[titleLabel.text]=' . $variables['title'];
      }

      // Add session to src url.
      if ($variables['options']['session']) {
        $variables['src'] .= '&flashvars[ks]=' . $variables['session'];
      }

      break;
  }
}
